from distutils.core import setup

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
  name = 'type_enforced',
  packages = ['type_enforced'],
  version = '0.0.12',
  license='MIT',
  description = 'A type enforcer for python type annotations',
  long_description=long_description,
  long_description_content_type='text/markdown',
  author = 'Connor Makowski',
  author_email = 'connor.m.makowski@gmail.com',
  url = 'https://github.com/connor-makowski/type_enforced',
  download_url = 'https://github.com/connor-makowski/type_enforced/dist/type_enforced-0.0.12.tar.gz',
  keywords = [],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
  ],
  python_requires=">=3.6, <4",
)



import type_enforced

@type_enforced.Enforcer
def my_fn(a: int , b: [int, str], c: int) -> None:
    return None

success_1=True
try:
    my_fn(a=1, b=2, c=3) # No Error
    my_fn(a=1, b='2', c=3) # No Error (b can take int or str)
except:
    success_1=False

success_2=False
try:
    my_fn(a='a', b=2, c=3) # Error (a can only accept int)
except Exception as e:
    if 'Type mismatch' in str(e):
        success_2=True

if success_1 and success_2:
    print('test_fn_1.py passed')
else:
    print('test_fn_1.py failed')



import type_enforced

@type_enforced.Enforcer
def my_fn(a: int , b: [int, str] =2, c: int =3) -> None:
    return 1

success=False

try:
    my_fn(a=1, b=2, c=3) # Error (return is not None)
except Exception as e:
    if 'Type mismatch' in str(e):
        success=True

if success:
    print('test_fn_2.py passed')
else:
    print('test_fn_2.py failed')



import type_enforced
import sys

class Foo():
    @type_enforced.Enforcer
    @classmethod
    def add(self, a:int, b:int) -> int:
        return a+b

    @type_enforced.Enforcer
    @staticmethod
    def subtract(a:int, b:int) -> int:
        return a-b

success = True

try:
    x = Foo.add(1,2)
    y = Foo.subtract(4,3)
    success = success and x == 3 and y == 1
except:
    success = False

try:
    Foo.add(1,2.0)
    success = False
except:
    pass

try:
    Foo.subtract(1,2.0)
    success = False
except:
    pass

# classmethod and staticmethod wrappers do not contain annotations prior to 3.9
if success or sys.version_info <= (3,10,0):
    print('test_class_6.py passed')
else:
    print('test_class_6.py failed')
